@@ -27,6 +27,9 @@
 @CREATED    : July 27, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: minc_convenience.c,v $
+ * Revision 6.12.2.1  2004/09/28 20:23:40  bert
+ * Minor portability fixes for Windows
+ *
  * Revision 6.12  2004/03/24 20:53:48  bert
  * Increase att_length by one in miappend_history() in order to read the entire attribute
  *
@@ -116,30 +119,29 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/minc_convenience.c,v 6.12 2004/03/24 20:53:48 bert Exp $ MINC (MNI)";
+static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/minc_convenience.c,v 6.12.2.1 2004/09/28 20:23:40 bert Exp $ MINC (MNI)";
 #endif
 
-#include "config.h"
-#include <type_limits.h>
-#include <minc_private.h>
-#include <minc_varlists.h>
+#include "minc_private.h"
+#include "type_limits.h"
+#include "minc_varlists.h"
 
 /* Private functions */
-private int MI_create_dim_variable(int cdfid, char *name, 
+PRIVATE int MI_create_dim_variable(int cdfid, char *name, 
                                    nc_type datatype, int ndims);
-private int MI_create_dimwidth_variable(int cdfid, char *name, 
+PRIVATE int MI_create_dimwidth_variable(int cdfid, char *name, 
                                         nc_type datatype, int ndims);
-private int MI_create_image_variable(int cdfid, char *name, nc_type datatype,
+PRIVATE int MI_create_image_variable(int cdfid, char *name, nc_type datatype,
                                      int ndims, int dim[]);
-private int MI_create_imaxmin_variable(int cdfid, char *name, nc_type datatype,
+PRIVATE int MI_create_imaxmin_variable(int cdfid, char *name, nc_type datatype,
                                        int ndims, int dim[]);
-private int MI_verify_maxmin_dims(int cdfid,
+PRIVATE int MI_verify_maxmin_dims(int cdfid,
                                   int image_ndims,  int image_dim[],
                                   int maxmin_ndims, int maxmin_dim[]);
-private int MI_create_root_variable(int cdfid, char *name);
-private int MI_create_simple_variable(int cdfid, char *name);
-private int MI_add_stdgroup(int cdfid, int varid);
-private int MI_is_in_list(char *string, char *list[]);
+PRIVATE int MI_create_root_variable(int cdfid, char *name);
+PRIVATE int MI_create_simple_variable(int cdfid, char *name);
+PRIVATE int MI_add_stdgroup(int cdfid, int varid);
+PRIVATE int MI_is_in_list(char *string, char *list[]);
 
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -156,7 +158,7 @@ private int MI_is_in_list(char *string, char *list[]);
 @CREATED    : August 15, 2001
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miget_datatype(int cdfid, int imgid, 
+MNCAPI int miget_datatype(int cdfid, int imgid, 
                           nc_type *datatype, int *is_signed)
 {
    int old_ncopts;
@@ -216,7 +218,7 @@ public int miget_datatype(int cdfid, int imgid,
 @CREATED    : August 15, 2001
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miget_default_range(nc_type datatype, int is_signed, 
+MNCAPI int miget_default_range(nc_type datatype, int is_signed, 
                                double default_range[])
 {
    MI_SAVE_ROUTINE_NAME("miget_default_range");
@@ -268,7 +270,7 @@ public int miget_default_range(nc_type datatype, int is_signed,
 @CREATED    : August 15, 2001
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miget_valid_range(int cdfid, int imgid, double valid_range[])
+MNCAPI int miget_valid_range(int cdfid, int imgid, double valid_range[])
 {
    int old_ncopts;
    int status;
@@ -368,7 +370,7 @@ public int miget_valid_range(int cdfid, int imgid, double valid_range[])
 @CREATED    : August 15, 2001
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miset_valid_range(int cdfid, int imgid, double valid_range[])
+MNCAPI int miset_valid_range(int cdfid, int imgid, double valid_range[])
 {
    nc_type datatype;
    int is_signed;
@@ -423,7 +425,7 @@ public int miset_valid_range(int cdfid, int imgid, double valid_range[])
 @CREATED    : October 19, 2001
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miget_image_range(int cdfid, double image_range[])
+MNCAPI int miget_image_range(int cdfid, double image_range[])
 {
    int oldncopts;                /* For saving value of ncopt */
    int vid[2];                   /* Variable ids for min and max */
@@ -557,7 +559,7 @@ public int miget_image_range(int cdfid, double image_range[])
 @CREATED    : October 22, 2001
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int mivar_exists(int cdfid, char *varname)
+MNCAPI int mivar_exists(int cdfid, char *varname)
 {
    int oldncopts;                /* For saving value of ncopt */
    int exists;                   /* Flag */
@@ -591,7 +593,7 @@ public int mivar_exists(int cdfid, char *varname)
 @CREATED    : August 5, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattput_pointer(int cdfid, int varid, char *name, int ptrvarid)
+MNCAPI int miattput_pointer(int cdfid, int varid, char *name, int ptrvarid)
 {
    /* String to hold pointer to variable */
    char pointer_string[MAX_NC_NAME+sizeof(MI_VARATT_POINTER_PREFIX)];
@@ -638,7 +640,7 @@ public int miattput_pointer(int cdfid, int varid, char *name, int ptrvarid)
 @CREATED    : August 5, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattget_pointer(int cdfid, int varid, char *name)
+MNCAPI int miattget_pointer(int cdfid, int varid, char *name)
 {
    /* Character string to hold attribute */
    char pointer_string[MAX_NC_NAME+sizeof(MI_VARATT_POINTER_PREFIX)];
@@ -686,7 +688,7 @@ public int miattget_pointer(int cdfid, int varid, char *name)
 @CREATED    : August 5, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miadd_child(int cdfid, int parent_varid, int child_varid)
+MNCAPI int miadd_child(int cdfid, int parent_varid, int child_varid)
 {
    char *child_list;           /* Pointer to string list of children */
    int child_list_size;        /* Length of child list string */
@@ -789,7 +791,7 @@ public int miadd_child(int cdfid, int parent_varid, int child_varid)
 @CREATED    : August 5, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micreate_std_variable(int cdfid, char *name, nc_type datatype, 
+MNCAPI int micreate_std_variable(int cdfid, char *name, nc_type datatype, 
                                  int ndims, int dim[])
 {
    int varid;                /* Created variable id */
@@ -860,7 +862,7 @@ public int micreate_std_variable(int cdfid, char *name, nc_type datatype,
 @CREATED    : August 5, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_create_dim_variable(int cdfid, char *name, 
+PRIVATE int MI_create_dim_variable(int cdfid, char *name, 
                                    nc_type datatype, int ndims)
 {
    int dimid;                /* Dimension id (for dimensions variables) */
@@ -936,7 +938,7 @@ private int MI_create_dim_variable(int cdfid, char *name,
 @CREATED    : August 5, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_create_dimwidth_variable(int cdfid, char *name, 
+PRIVATE int MI_create_dimwidth_variable(int cdfid, char *name, 
                                         nc_type datatype, int ndims)
 {
    int dimid;                /* Dimension id (for dimensions variables) */
@@ -996,7 +998,7 @@ private int MI_create_dimwidth_variable(int cdfid, char *name,
 @CREATED    : August 6, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_create_image_variable(int cdfid, char *name, nc_type datatype,
+PRIVATE int MI_create_image_variable(int cdfid, char *name, nc_type datatype,
                                      int ndims, int dim[])
 {
    int varid;                /* Created variable id */
@@ -1067,7 +1069,7 @@ private int MI_create_image_variable(int cdfid, char *name, nc_type datatype,
 @CREATED    : August 6, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_create_imaxmin_variable(int cdfid, char *name, nc_type datatype,
+PRIVATE int MI_create_imaxmin_variable(int cdfid, char *name, nc_type datatype,
                                        int ndims, int dim[])
 {
    int varid;                /* Created variable id */
@@ -1146,7 +1148,7 @@ private int MI_create_imaxmin_variable(int cdfid, char *name, nc_type datatype,
 @CREATED    : August 7, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_verify_maxmin_dims(int cdfid,
+PRIVATE int MI_verify_maxmin_dims(int cdfid,
                                   int image_ndims,  int image_dim[],
                                   int maxmin_ndims, int maxmin_dim[])
 {
@@ -1190,7 +1192,7 @@ private int MI_verify_maxmin_dims(int cdfid,
 @CREATED    : August 6, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_create_root_variable(int cdfid, char *name)
+PRIVATE int MI_create_root_variable(int cdfid, char *name)
 {
    int varid;                /* Created variable id */
 
@@ -1225,7 +1227,7 @@ private int MI_create_root_variable(int cdfid, char *name)
 @CREATED    : August 6, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_create_simple_variable(int cdfid, char *name)
+PRIVATE int MI_create_simple_variable(int cdfid, char *name)
 {
    int varid;                /* Created variable id */
 
@@ -1256,7 +1258,7 @@ private int MI_create_simple_variable(int cdfid, char *name)
 @CREATED    : August 6, 1992
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_add_stdgroup(int cdfid, int varid)
+PRIVATE int MI_add_stdgroup(int cdfid, int varid)
 {
    int root_varid;          /* Id of root variable */
    int oldncopts;           /* Old value of ncopts */
@@ -1299,7 +1301,7 @@ private int MI_add_stdgroup(int cdfid, int varid)
 @CREATED    : August 6, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micreate_group_variable(int cdfid, char *name)
+MNCAPI int micreate_group_variable(int cdfid, char *name)
 {
    int varid;
 
@@ -1326,7 +1328,7 @@ public int micreate_group_variable(int cdfid, char *name)
 @CREATED    : January 1, 2004 (Bert Vincent)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int
+MNCAPI int
 miappend_history(int fd, const char *tm_stamp)
 {
     nc_type att_type;
@@ -1392,7 +1394,7 @@ miappend_history(int fd, const char *tm_stamp)
 @CREATED    : August 5, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_is_in_list(char *string, char *list[])
+PRIVATE int MI_is_in_list(char *string, char *list[])
 {
    int i;
 
