@@ -36,6 +36,9 @@
 @CREATED    : July 27, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: netcdf_convenience.c,v $
+ * Revision 6.10.2.1  2004/09/28 20:23:40  bert
+ * Minor portability fixes for Windows
+ *
  * Revision 6.10  2004/03/23 21:16:05  bert
  * Conditionally include fcntl.h
  *
@@ -142,11 +145,10 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/netcdf_convenience.c,v 6.10 2004/03/23 21:16:05 bert Exp $ MINC (MNI)";
+static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/netcdf_convenience.c,v 6.10.2.1 2004/09/28 20:23:40 bert Exp $ MINC (MNI)";
 #endif
 
-#include "config.h"             /* From configure */
-#include <minc_private.h>
+#include "minc_private.h"
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -164,10 +166,10 @@ static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/netcdf
 #include <fcntl.h>
 #endif
 
-/* Private functions */
-private int execute_decompress_command(char *command, char *infile, 
+/* PRIVATE functions */
+PRIVATE int execute_decompress_command(char *command, char *infile, 
                                        char *outfile, int header_only);
-private int MI_vcopy_action(int ndims, long start[], long count[], 
+PRIVATE int MI_vcopy_action(int ndims, long start[], long count[], 
                             long nvalues, void *var_buffer, void *caller_data);
 
 
@@ -190,7 +192,7 @@ private int MI_vcopy_action(int ndims, long start[], long count[],
 @CREATED    : January 20, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int execute_decompress_command(char *command, char *infile, 
+PRIVATE int execute_decompress_command(char *command, char *infile, 
                                        char *outfile, int header_only)
 {
    int oldncopts;
@@ -337,7 +339,7 @@ private int execute_decompress_command(char *command, char *infile,
 @CREATED    : January 20, 1995 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public char *miexpand_file(char *path, char *tempfile, int header_only,
+MNCAPI char *miexpand_file(char *path, char *tempfile, int header_only,
                            int *created_tempfile)
 {
    typedef enum 
@@ -510,7 +512,7 @@ public char *miexpand_file(char *path, char *tempfile, int header_only,
 @CREATED    : November 2, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miopen(char *path, int mode)
+MNCAPI int miopen(char *path, int mode)
 {
    int status, oldncopts, created_tempfile;
    char *tempfile;
@@ -567,7 +569,7 @@ public int miopen(char *path, int mode)
 @CREATED    : November 2, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micreate(char *path, int cmode)
+MNCAPI int micreate(char *path, int cmode)
 {
    int status;
 
@@ -591,7 +593,7 @@ public int micreate(char *path, int cmode)
 @CREATED    : November 2, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miclose(int cdfid)
+MNCAPI int miclose(int cdfid)
 {
    int status;
 
@@ -627,7 +629,7 @@ public int miclose(int cdfid)
 @MODIFIED   : August 20, 2001 (P.N.)
                  - changed to call miattget_with_sign
 ---------------------------------------------------------------------------- */
-public int miattget(int cdfid, int varid, char *name, nc_type datatype,
+MNCAPI int miattget(int cdfid, int varid, char *name, nc_type datatype,
                     int max_length, void *value, int *att_length)
 {
    MI_SAVE_ROUTINE_NAME("miattget");
@@ -667,7 +669,7 @@ public int miattget(int cdfid, int varid, char *name, nc_type datatype,
                  - slightly modified version of old miattget
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattget_with_sign(int cdfid, int varid, char *name, 
+MNCAPI int miattget_with_sign(int cdfid, int varid, char *name, 
                               char *insign, nc_type datatype, char *outsign,
                               int max_length, void *value, int *att_length)
 {
@@ -752,7 +754,7 @@ public int miattget_with_sign(int cdfid, int varid, char *name,
 @CREATED    : July 27, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattget1(int cdfid, int varid, char *name, nc_type datatype,
+MNCAPI int miattget1(int cdfid, int varid, char *name, nc_type datatype,
                     void *value)
 {
    int att_length;      /* Actual length of the attribute */
@@ -791,7 +793,7 @@ public int miattget1(int cdfid, int varid, char *name, nc_type datatype,
 @CREATED    : July 28, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public char *miattgetstr(int cdfid, int varid, char *name, 
+MNCAPI char *miattgetstr(int cdfid, int varid, char *name, 
                          int maxlen, char *value)
 {
    nc_type att_type;          /* Type of attribute */
@@ -866,7 +868,7 @@ public char *miattgetstr(int cdfid, int varid, char *name,
 @CREATED    : November 25, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattputint(int cdfid, int varid, char *name, int value)
+MNCAPI int miattputint(int cdfid, int varid, char *name, int value)
 {
    int lvalue;
 
@@ -893,7 +895,7 @@ public int miattputint(int cdfid, int varid, char *name, int value)
 @CREATED    : August 5, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattputdbl(int cdfid, int varid, char *name, double value)
+MNCAPI int miattputdbl(int cdfid, int varid, char *name, double value)
 {
    MI_SAVE_ROUTINE_NAME("miattputdbl");
 
@@ -917,7 +919,7 @@ public int miattputdbl(int cdfid, int varid, char *name, double value)
 @CREATED    : July 28, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int miattputstr(int cdfid, int varid, char *name, char *value)
+MNCAPI int miattputstr(int cdfid, int varid, char *name, char *value)
 {
    MI_SAVE_ROUTINE_NAME("miattputstr");
 
@@ -952,7 +954,7 @@ public int miattputstr(int cdfid, int varid, char *name, char *value)
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int mivarget(int cdfid, int varid, long start[], long count[],
+MNCAPI int mivarget(int cdfid, int varid, long start[], long count[],
                     nc_type datatype, char *sign, void *values)
 {
    MI_SAVE_ROUTINE_NAME("mivarget");
@@ -988,7 +990,7 @@ public int mivarget(int cdfid, int varid, long start[], long count[],
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int mivarget1(int cdfid, int varid, long mindex[],
+MNCAPI int mivarget1(int cdfid, int varid, long mindex[],
                      nc_type datatype, char *sign, void *value)
 {
    long count[MAX_VAR_DIMS];
@@ -1029,7 +1031,7 @@ public int mivarget1(int cdfid, int varid, long mindex[],
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int mivarput(int cdfid, int varid, long start[], long count[],
+MNCAPI int mivarput(int cdfid, int varid, long start[], long count[],
                     nc_type datatype, char *sign, void *values)
 {
    MI_SAVE_ROUTINE_NAME("mivarput");
@@ -1065,7 +1067,7 @@ public int mivarput(int cdfid, int varid, long start[], long count[],
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int mivarput1(int cdfid, int varid, long mindex[],
+MNCAPI int mivarput1(int cdfid, int varid, long mindex[],
                      nc_type datatype, char *sign, void *value)
 {
    long count[MAX_VAR_DIMS];
@@ -1093,7 +1095,7 @@ public int mivarput1(int cdfid, int varid, long mindex[],
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public long *miset_coords(int nvals, long value, long coords[])
+MNCAPI long *miset_coords(int nvals, long value, long coords[])
 {
    int i;
 
@@ -1128,7 +1130,7 @@ public long *miset_coords(int nvals, long value, long coords[])
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public long *mitranslate_coords(int cdfid, 
+MNCAPI long *mitranslate_coords(int cdfid, 
                                 int invar,  long incoords[],
                                 int outvar, long outcoords[])
 {
@@ -1185,7 +1187,7 @@ public long *mitranslate_coords(int cdfid,
 @CREATED    : 
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micopy_all_atts(int incdfid, int invarid, 
+MNCAPI int micopy_all_atts(int incdfid, int invarid, 
                            int outcdfid, int outvarid)
 {
    int num_atts;             /* Number of attributes */
@@ -1251,7 +1253,7 @@ public int micopy_all_atts(int incdfid, int invarid,
 @CREATED    : 
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micopy_var_def(int incdfid, int invarid, int outcdfid)
+MNCAPI int micopy_var_def(int incdfid, int invarid, int outcdfid)
 {
    char varname[MAX_NC_NAME]; /* Name of variable */
    char dimname[MAX_NC_NAME]; /* Name of dimension */
@@ -1338,7 +1340,7 @@ public int micopy_var_def(int incdfid, int invarid, int outcdfid)
 @CREATED    : 
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micopy_var_values(int incdfid, int invarid, 
+MNCAPI int micopy_var_values(int incdfid, int invarid, 
                              int outcdfid, int outvarid)
 {
    nc_type intype, outtype;   /* Data types */
@@ -1408,7 +1410,7 @@ public int micopy_var_values(int incdfid, int invarid,
 @CREATED    : August 3, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_vcopy_action(int ndims, long start[], long count[], 
+PRIVATE int MI_vcopy_action(int ndims, long start[], long count[], 
                             long nvalues, void *var_buffer, void *caller_data)
      /* ARGSUSED */
 {
@@ -1447,7 +1449,7 @@ private int MI_vcopy_action(int ndims, long start[], long count[],
 @CREATED    : August 3, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micopy_all_var_defs(int incdfid, int outcdfid, int nexclude,
+MNCAPI int micopy_all_var_defs(int incdfid, int outcdfid, int nexclude,
                                int excluded_vars[])
 {
    int num_vars;          /* Number of variables in input file */
@@ -1509,7 +1511,7 @@ public int micopy_all_var_defs(int incdfid, int outcdfid, int nexclude,
 @CREATED    : 
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int micopy_all_var_values(int incdfid, int outcdfid, int nexclude,
+MNCAPI int micopy_all_var_values(int incdfid, int outcdfid, int nexclude,
                                  int excluded_vars[])
 {
    int num_vars;           /* Number of variables in input file */
@@ -1567,7 +1569,7 @@ public int micopy_all_var_values(int incdfid, int outcdfid, int nexclude,
 #define P_tmpdir "/var/tmp"
 #endif /* P_tmpdir not defined */
 
-public char *
+MNCAPI char *
 micreate_tempfile(void)
 {
   int tmp_fd;
