@@ -14,6 +14,9 @@
 @CREATED    : July 27, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: value_conversion.c,v $
+ * Revision 6.4.2.1  2004/09/28 20:23:40  bert
+ * Minor portability fixes for Windows
+ *
  * Revision 6.4  2003/11/14 16:52:24  stever
  * More last-minute fixes.
  *
@@ -82,17 +85,17 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/value_conversion.c,v 6.4 2003/11/14 16:52:24 stever Exp $ MINC (MNI)";
+static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/value_conversion.c,v 6.4.2.1 2004/09/28 20:23:40 bert Exp $ MINC (MNI)";
 #endif
 
+#include "minc_private.h"
 #include <math.h>
-#include <type_limits.h>
-#include <minc_private.h>
+#include "type_limits.h"
 
 /* Private functions */
-private int MI_var_action(int ndims, long var_start[], long var_count[], 
+PRIVATE int MI_var_action(int ndims, long var_start[], long var_count[], 
                           long nvalues, void *var_buffer, void *caller_data);
-private int MI_get_sign(nc_type datatype, int sign);
+PRIVATE int MI_get_sign(nc_type datatype, int sign);
 
 
 
@@ -146,7 +149,7 @@ private int MI_get_sign(nc_type datatype, int sign);
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-semiprivate int MI_varaccess(int operation, int cdfid, int varid, 
+SEMIPRIVATE int MI_varaccess(int operation, int cdfid, int varid, 
                              long start[], long count[],
                              nc_type datatype, int sign, void *values,
                              int *bufsize_step, mi_icv_type *icvp)
@@ -252,7 +255,7 @@ semiprivate int MI_varaccess(int operation, int cdfid, int varid,
 @CREATED    : July 30, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_var_action(int ndims, long var_start[], long var_count[], 
+PRIVATE int MI_var_action(int ndims, long var_start[], long var_count[], 
                           long nvalues, void *var_buffer, void *caller_data)
      /* ARGSUSED */
 {
@@ -349,7 +352,7 @@ private int MI_var_action(int ndims, long var_start[], long var_count[],
 @CREATED    : July 29, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-semiprivate int MI_var_loop(int ndims, long start[], long count[],
+SEMIPRIVATE int MI_var_loop(int ndims, long start[], long count[],
                             int value_size, int *bufsize_step,
                             long max_buffer_size,
                             void *caller_data,
@@ -465,7 +468,7 @@ semiprivate int MI_var_loop(int ndims, long start[], long count[],
 @CREATED    : July 30, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-semiprivate int MI_get_sign_from_string(nc_type datatype, char *sign)
+SEMIPRIVATE int MI_get_sign_from_string(nc_type datatype, char *sign)
 {
    MI_SAVE_ROUTINE_NAME("MI_get_sign_from_string");
 
@@ -500,7 +503,7 @@ semiprivate int MI_get_sign_from_string(nc_type datatype, char *sign)
 @CREATED    : July 27, 1992 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-private int MI_get_sign(nc_type datatype, int sign)
+PRIVATE int MI_get_sign(nc_type datatype, int sign)
 {
    MI_SAVE_ROUTINE_NAME("MI_get_sign");
 
@@ -553,7 +556,7 @@ private int MI_get_sign(nc_type datatype, int sign)
 @MODIFIED   : August 28, 1992 (P.N.)
                  - replaced type conversions with macros
 ---------------------------------------------------------------------------- */
-semiprivate int MI_convert_type(long number_of_values,
+SEMIPRIVATE int MI_convert_type(long number_of_values,
                                 nc_type intype,  int insign,  void *invalues,
                                 nc_type outtype, int outsign, void *outvalues,
                                 mi_icv_type *icvp)
