@@ -13,6 +13,9 @@
 @CREATED    : March 10, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincreshape.c,v $
+ * Revision 6.8.2.1  2005/03/16 19:02:51  bert
+ * Port changes from 2.0 branch
+ *
  * Revision 6.8  2001/11/13 14:16:50  neelin
  * Get correct valid range for conversion from int to float types
  *
@@ -89,7 +92,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincreshape/mincreshape.c,v 6.8 2001/11/13 14:16:50 neelin Exp $";
+static char rcsid[]="$Header: /software/source/minc/progs/mincreshape/mincreshape.c,v 6.8.2.1 2005/03/16 19:02:51 bert Exp $";
 #endif
 
 #include <stdlib.h>
@@ -102,12 +105,11 @@ static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/mincresha
 #include <minc.h>
 #include <ParseArgv.h>
 #include <time_stamp.h>
-#include <minc_def.h>
 #include "mincreshape.h"
 
 /* Main program */
 
-public int main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
    Reshape_info reshape_info;
 
@@ -120,7 +122,9 @@ public int main(int argc, char *argv[])
    /* Close the output file */
    (void) miattputstr(reshape_info.outmincid, reshape_info.outimgid,
                       MIcomplete, MI_TRUE);
+
    (void) miclose(reshape_info.outmincid);
+   (void) miclose(reshape_info.inmincid);
 
    exit(EXIT_SUCCESS);
 }
@@ -139,7 +143,7 @@ public int main(int argc, char *argv[])
 @CREATED    : March 11, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void get_arginfo(int argc, char *argv[],
+static void get_arginfo(int argc, char *argv[],
                         Reshape_info *reshape_info)
 {
 
@@ -447,7 +451,7 @@ public void get_arginfo(int argc, char *argv[],
 @CREATED    : March 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_fillvalue(char *dst, char *key, char *nextArg)
+static int get_fillvalue(char *dst, char *key, char *nextArg)
      /* ARGSUSED */
 {
    double *dptr;
@@ -482,7 +486,7 @@ public int get_fillvalue(char *dst, char *key, char *nextArg)
 @CREATED    : March 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_dimsize(char *dst, char *key, char *nextArg)
+static int get_dimsize(char *dst, char *key, char *nextArg)
      /* ARGSUSED */
 {
    Dimsize_list *dimsize_list;
@@ -568,7 +572,7 @@ public int get_dimsize(char *dst, char *key, char *nextArg)
 @CREATED    : March 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_axis_order(char *dst, char *key, char *nextArg)
+static int get_axis_order(char *dst, char *key, char *nextArg)
      /* ARGSUSED */
 {
    char **axis_order;
@@ -659,7 +663,7 @@ public int get_axis_order(char *dst, char *key, char *nextArg)
 @CREATED    : March 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_axis_range(char *dst, char *key, char *nextArg)
+static int get_axis_range(char *dst, char *key, char *nextArg)
      /* ARGSUSED */
 {
    Axis_ranges *axis_ranges;
@@ -759,7 +763,7 @@ public int get_axis_range(char *dst, char *key, char *nextArg)
 @CREATED    : June 10, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public int get_arg_vector(char *dst, char *key, char *nextArg)
+static int get_arg_vector(char *dst, char *key, char *nextArg)
      /* ARGSUSED */
 {
 
@@ -834,7 +838,7 @@ public int get_arg_vector(char *dst, char *key, char *nextArg)
 @CREATED    : March 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void get_default_datatype(int mincid, nc_type *datatype, int *is_signed,
+static void get_default_datatype(int mincid, nc_type *datatype, int *is_signed,
                                  double valid_range[2])
 {
    int imgid;
@@ -932,7 +936,7 @@ public void get_default_datatype(int mincid, nc_type *datatype, int *is_signed,
 @CREATED    : May 18, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void setup_dim_sizes(int icvid, int mincid, Dimsize_list *dimsize_list)
+static void setup_dim_sizes(int icvid, int mincid, Dimsize_list *dimsize_list)
 {
    int ientry, idim;
    int imgid, dimid;
@@ -1002,7 +1006,7 @@ public void setup_dim_sizes(int icvid, int mincid, Dimsize_list *dimsize_list)
 @CREATED    : May 26, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void setup_reshaping_info(int icvid, int mincid, 
+static void setup_reshaping_info(int icvid, int mincid, 
                                  int do_norm, double fillvalue, int do_scalar,
                                  char *axis_order[], Axis_ranges *axis_ranges,
                                  long hs_start[], long hs_count[],
@@ -1290,7 +1294,7 @@ public void setup_reshaping_info(int icvid, int mincid,
 @CREATED    : June 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void setup_output_file(int mincid, char *history, 
+static void setup_output_file(int mincid, char *history, 
                               Reshape_info *reshape_info)
 {
    int output_ndims, output_dim[MAX_VAR_DIMS];
@@ -1418,13 +1422,13 @@ public void setup_output_file(int mincid, char *history,
         == MI_ERROR) || (datatype != NC_CHAR))
       att_length = 0;
    att_length += strlen(history) + 1;
-   string = MALLOC(att_length);
+   string = malloc(att_length);
    string[0] = '\0';
    (void) miattgetstr(mincid, NC_GLOBAL, MIhistory, att_length, string);
    ncopts = NCOPTS_DEFAULT;
    (void) strcat(string, history);
    (void) miattputstr(mincid, NC_GLOBAL, MIhistory, string);
-   FREE(string);
+   free(string);
 
    /* Get into data mode */
    (void) ncsetfill(mincid, NC_NOFILL);
@@ -1464,7 +1468,7 @@ public void setup_output_file(int mincid, char *history,
 @CREATED    : June 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void create_dim_var(int outmincid, int outdimid,
+static void create_dim_var(int outmincid, int outdimid,
                            int inicvid, int cur_image_dim, int inmincid, 
                            long input_start, long input_count)
 {
@@ -1577,7 +1581,7 @@ public void create_dim_var(int outmincid, int outdimid,
 @CREATED    : June 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void copy_dimension_values(int outmincid, int outdimid, int inmincid,
+static void copy_dimension_values(int outmincid, int outdimid, int inmincid,
                                   long input_start, long input_count)
 {
    char dimname[MAX_NC_NAME];
@@ -1616,7 +1620,7 @@ public void copy_dimension_values(int outmincid, int outdimid, int inmincid,
 @CREATED    : June 16, 1994 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-public void copy_dim_var_values(int outmincid, char *dimname, char *varname,
+static void copy_dim_var_values(int outmincid, char *dimname, char *varname,
                                 int inmincid,
                                 long input_start, long input_count)
 {
