@@ -10,6 +10,9 @@
 @CREATED    : August 13, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: xfminvert.c,v $
+ * Revision 6.2.2.1  2005/03/16 19:02:52  bert
+ * Port changes from 2.0 branch
+ *
  * Revision 6.2  2004/02/02 18:24:11  bert
  * Call ParseArgv() so that version information will be available
  *
@@ -60,7 +63,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/xfm/xfminvert.c,v 6.2 2004/02/02 18:24:11 bert Exp $";
+static char rcsid[]="$Header: /software/source/minc/progs/xfm/xfminvert.c,v 6.2.2.1 2005/03/16 19:02:52 bert Exp $";
 #endif
 
 #include <stdlib.h>
@@ -68,17 +71,12 @@ static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/xfm/xfmin
 #include <string.h>
 #include <volume_io.h>
 #include <ParseArgv.h>
-#include <minc_def.h>
 
 /* Constants */
 #ifndef TRUE
 #  define TRUE 1
 #  define FALSE 0
 #endif
-#ifndef public
-#  define public
-#  define private static
-#endif
 
 /* Argument table */
 ArgvInfo argTable[] = {
